summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorQt Continuous Integration System <qt-info@nokia.com>2011-07-03 21:46:09 +1000
committerQt Continuous Integration System <qt-info@nokia.com>2011-07-03 21:46:09 +1000
commit1d5041c712acd10020c38a92f1eedc88368ca19f (patch)
treefb2d4e31c8232456d10bd70a67000076c8d2d48a
parent68ad4618e02d1686e37b979fbf1fd1f349aa6d4f (diff)
parent7f5797a784e237672f291055020ef4bbb6199893 (diff)
Merge branch 'master' of scm.dev.nokia.troll.no:qt/oslo-staging-1 into master-integrationv4.8.0-beta
* 'master' of scm.dev.nokia.troll.no:qt/oslo-staging-1: Doc: Fixing typo
-rw-r--r--tests/auto/qaccessibility/tst_qaccessibility.cpp4
-rw-r--r--tests/auto/qlistwidget/tst_qlistwidget.cpp18
-rw-r--r--tests/auto/qmenubar/tst_qmenubar.cpp2
-rw-r--r--tests/auto/qmutexlocker/tst_qmutexlocker.cpp2
-rw-r--r--tests/auto/qnetworkreply/tst_qnetworkreply.cpp8
-rw-r--r--tests/auto/qnetworksession/test/tst_qnetworksession.cpp20
-rw-r--r--tests/auto/qreadlocker/tst_qreadlocker.cpp2
-rw-r--r--tests/auto/qreadwritelock/tst_qreadwritelock.cpp6
-rw-r--r--tests/auto/qscriptengineagent/tst_qscriptengineagent.cpp4
-rw-r--r--tests/auto/qsortfilterproxymodel/tst_qsortfilterproxymodel.cpp2
-rw-r--r--tests/auto/qstylesheetstyle/tst_qstylesheetstyle.cpp2
-rw-r--r--tests/auto/qsvgrenderer/tst_qsvgrenderer.cpp6
-rw-r--r--tests/auto/qtextcodec/tst_qtextcodec.cpp2
-rw-r--r--tests/auto/qtextcursor/tst_qtextcursor.cpp2
-rw-r--r--tests/auto/qvector/tst_qvector.cpp2
-rw-r--r--tests/auto/qwizard/tst_qwizard.cpp2
-rw-r--r--tests/auto/qwritelocker/tst_qwritelocker.cpp2
-rw-r--r--tests/auto/qwswindowsystem/tst_qwswindowsystem.cpp6
-rw-r--r--tests/auto/selftests/subtest/tst_subtest.cpp2
-rw-r--r--tests/auto/uiloader/tst_screenshot/main.cpp2
20 files changed, 48 insertions, 48 deletions
diff --git a/tests/auto/qaccessibility/tst_qaccessibility.cpp b/tests/auto/qaccessibility/tst_qaccessibility.cpp
index 7b70a5e6a6..aedb87ef03 100644
--- a/tests/auto/qaccessibility/tst_qaccessibility.cpp
+++ b/tests/auto/qaccessibility/tst_qaccessibility.cpp
@@ -1830,7 +1830,7 @@ void tst_QAccessibility::buttonTest()
menuToolButton.setPopup(&toolMenu);
menuToolButton.setMinimumSize(20,20);
- // splitted menu toolbutton
+ // split menu toolbutton
QToolButton splitToolButton(&window);
splitToolButton.setTextLabel("Split Tool");
Q3PopupMenu splitMenu(&splitToolButton);
@@ -1951,7 +1951,7 @@ void tst_QAccessibility::buttonTest()
// QCOMPARE(test->actionText(QAccessible::Press, QAccessible::Name, 0), QString("Press"));
// test->release();
-// // test splitted menu toolbutton
+// // test split menu toolbutton
// QVERIFY(QAccessible::queryAccessibleInterface(&splitToolButton, &test));
// QCOMPARE(test->childCount(), 2);
// QCOMPARE(test->role(0), QAccessible::ButtonDropDown);
diff --git a/tests/auto/qlistwidget/tst_qlistwidget.cpp b/tests/auto/qlistwidget/tst_qlistwidget.cpp
index 50ad3397ce..c53ded3a97 100644
--- a/tests/auto/qlistwidget/tst_qlistwidget.cpp
+++ b/tests/auto/qlistwidget/tst_qlistwidget.cpp
@@ -260,7 +260,7 @@ void tst_QListWidget::addItem2()
{
int count = testWidget->count();
- // Boundry Checking
+ // Boundary Checking
testWidget->addItem(0);
QCOMPARE(testWidget->count(), count);
@@ -276,7 +276,7 @@ void tst_QListWidget::addItems()
{
int count = testWidget->count();
- // Boundry Checking
+ // Boundary Checking
testWidget->addItems(QStringList());
QCOMPARE(testWidget->count(), count);
@@ -294,7 +294,7 @@ void tst_QListWidget::addItems()
void tst_QListWidget::openPersistentEditor()
{
- // Boundry checking
+ // Boundary checking
testWidget->openPersistentEditor(0);
QListWidgetItem *item = new QListWidgetItem(QString("%1").arg(testWidget->count()));
testWidget->openPersistentEditor(item);
@@ -312,7 +312,7 @@ void tst_QListWidget::closePersistentEditor()
QTest::qWait(1000);
#endif
- // Boundry checking
+ // Boundary checking
int childCount = testWidget->viewport()->children().count();
testWidget->closePersistentEditor(0);
QListWidgetItem *item = new QListWidgetItem(QString("%1").arg(testWidget->count()));
@@ -337,7 +337,7 @@ void tst_QListWidget::closePersistentEditor()
void tst_QListWidget::setItemHidden()
{
- // Boundry checking
+ // Boundary checking
testWidget->setItemHidden(0, true);
testWidget->setItemHidden(0, false);
@@ -394,7 +394,7 @@ void tst_QListWidget::setCurrentItem()
for (int i = 0; i < fill; ++i)
testWidget->addItem(QString("%1").arg(i));
- // Boundry checking
+ // Boundary checking
testWidget->setCurrentItem((QListWidgetItem *)0);
QCOMPARE((QListWidgetItem *)0, testWidget->currentItem());
QListWidgetItem item;
@@ -426,7 +426,7 @@ void tst_QListWidget::setCurrentRow()
for (int i = 0; i < fill; ++i)
testWidget->addItem(QString("%1").arg(i));
- // Boundry checking
+ // Boundary checking
testWidget->setCurrentRow(-1);
QCOMPARE(-1, testWidget->currentRow());
testWidget->setCurrentRow(testWidget->count());
@@ -483,7 +483,7 @@ void tst_QListWidget::editItem_data()
void tst_QListWidget::editItem()
{
- // Boundry checking
+ // Boundary checking
testWidget->editItem(0);
QListWidgetItem *item = new QListWidgetItem(QString("%1").arg(testWidget->count()));
testWidget->editItem(item);
@@ -517,7 +517,7 @@ void tst_QListWidget::findItems()
{
// This really just tests that the items that are returned are converted from index's to items correctly.
- // Boundry checking
+ // Boundary checking
QCOMPARE(testWidget->findItems("GirlsCanWearJeansAndCutTheirHairShort", Qt::MatchExactly).count(), 0);
populate();
diff --git a/tests/auto/qmenubar/tst_qmenubar.cpp b/tests/auto/qmenubar/tst_qmenubar.cpp
index d548a51a33..ccfb670163 100644
--- a/tests/auto/qmenubar/tst_qmenubar.cpp
+++ b/tests/auto/qmenubar/tst_qmenubar.cpp
@@ -250,7 +250,7 @@ const int RESET = 0;
/*!
Test plan:
- insertItem (all flavours and combinations)
+ insertItem (all flavors and combinations)
removing menu items
clearing the menu
diff --git a/tests/auto/qmutexlocker/tst_qmutexlocker.cpp b/tests/auto/qmutexlocker/tst_qmutexlocker.cpp
index c9821f58c2..a663b60be7 100644
--- a/tests/auto/qmutexlocker/tst_qmutexlocker.cpp
+++ b/tests/auto/qmutexlocker/tst_qmutexlocker.cpp
@@ -182,7 +182,7 @@ void tst_QMutexLocker::unlockAndRelockTest()
releaseThread();
waitForThread();
- // mutex has been explicity relocked via QMutexLocker
+ // mutex has been explicitly relocked via QMutexLocker
QVERIFY(!thread->mutex.tryLock());
releaseThread();
diff --git a/tests/auto/qnetworkreply/tst_qnetworkreply.cpp b/tests/auto/qnetworkreply/tst_qnetworkreply.cpp
index 45f501ca06..f56176a43c 100644
--- a/tests/auto/qnetworkreply/tst_qnetworkreply.cpp
+++ b/tests/auto/qnetworkreply/tst_qnetworkreply.cpp
@@ -2518,7 +2518,7 @@ void tst_QNetworkReply::ioGetFromFile()
QNetworkRequest request(QUrl::fromLocalFile(file.fileName()));
QNetworkReplyPtr reply = manager.get(request);
- QVERIFY(reply->isFinished()); // a file should immediatly be done
+ QVERIFY(reply->isFinished()); // a file should immediately be done
DataReader reader(reply);
connect(reply, SIGNAL(finished()), &QTestEventLoop::instance(), SLOT(exitLoop()));
@@ -2808,7 +2808,7 @@ void tst_QNetworkReply::ioGetFromHttpWithAuth()
void tst_QNetworkReply::ioGetFromHttpWithAuthSynchronous()
{
// verify that we do not enter an endless loop with synchronous calls and wrong credentials
- // the case when we succed with the login is tested in ioGetFromHttpWithAuth()
+ // the case when we succeed with the login is tested in ioGetFromHttpWithAuth()
QNetworkRequest request(QUrl("http://" + QtNetworkSettings::serverName() + "/qtest/rfcs-auth/rfc3252.txt"));
request.setAttribute(
@@ -2917,7 +2917,7 @@ void tst_QNetworkReply::ioGetFromHttpWithProxyAuth()
void tst_QNetworkReply::ioGetFromHttpWithProxyAuthSynchronous()
{
// verify that we do not enter an endless loop with synchronous calls and wrong credentials
- // the case when we succed with the login is tested in ioGetFromHttpWithAuth()
+ // the case when we succeed with the login is tested in ioGetFromHttpWithAuth()
QNetworkProxy proxy(QNetworkProxy::HttpCachingProxy, QtNetworkSettings::serverName(), 3129);
QNetworkRequest request(QUrl("http://" + QtNetworkSettings::serverName() + "/qtest/rfc3252.txt"));
@@ -6236,7 +6236,7 @@ void tst_QNetworkReply::httpAbort()
QCOMPARE(reply->error(), QNetworkReply::OperationCanceledError);
QVERIFY(reply->isFinished());
- // Abort immediatly after the get()
+ // Abort immediately after the get()
QNetworkReplyPtr reply2 = manager.get(request);
connect(reply2, SIGNAL(finished()), &QTestEventLoop::instance(), SLOT(exitLoop()));
reply2->abort();
diff --git a/tests/auto/qreadlocker/tst_qreadlocker.cpp b/tests/auto/qreadlocker/tst_qreadlocker.cpp
index 7e9700fe5d..3ec9f1cb25 100644
--- a/tests/auto/qreadlocker/tst_qreadlocker.cpp
+++ b/tests/auto/qreadlocker/tst_qreadlocker.cpp
@@ -177,7 +177,7 @@ void tst_QReadLocker::unlockAndRelockTest()
releaseThread();
waitForThread();
- // lock has been explicity relocked via QReadLocker
+ // lock has been explicitly relocked via QReadLocker
QVERIFY(!thread->lock.tryLockForWrite());
releaseThread();
diff --git a/tests/auto/qreadwritelock/tst_qreadwritelock.cpp b/tests/auto/qreadwritelock/tst_qreadwritelock.cpp
index 720f2b0d67..18bd65f2f5 100644
--- a/tests/auto/qreadwritelock/tst_qreadwritelock.cpp
+++ b/tests/auto/qreadwritelock/tst_qreadwritelock.cpp
@@ -665,7 +665,7 @@ public:
/*
- A writer aquires a read-lock, a reader locks
+ A writer adquires a read-lock, a reader locks
the writer releases the lock, the reader gets the lock
*/
void tst_QReadWriteLock::readLockBlockRelease()
@@ -682,7 +682,7 @@ void tst_QReadWriteLock::readLockBlockRelease()
}
/*
- writer1 aquires a read-lock, writer2 blocks,
+ writer1 adquires a read-lock, writer2 blocks,
writer1 releases the lock, writer2 gets the lock
*/
void tst_QReadWriteLock::writeLockBlockRelease()
@@ -698,7 +698,7 @@ void tst_QReadWriteLock::writeLockBlockRelease()
QVERIFY(threadDone);
}
/*
- Two readers aquire a read-lock, one writer attempts a write block,
+ Two readers adquire a read-lock, one writer attempts a write block,
the readers release their locks, the writer gets the lock.
*/
void tst_QReadWriteLock::multipleReadersBlockRelease()
diff --git a/tests/auto/qscriptengineagent/tst_qscriptengineagent.cpp b/tests/auto/qscriptengineagent/tst_qscriptengineagent.cpp
index 2390f19fdd..7da647da81 100644
--- a/tests/auto/qscriptengineagent/tst_qscriptengineagent.cpp
+++ b/tests/auto/qscriptengineagent/tst_qscriptengineagent.cpp
@@ -815,7 +815,7 @@ void tst_QScriptEngineAgent::functionEntryAndExit_native2()
/** check behaiviour of native function throwing error*/
void tst_QScriptEngineAgent::functionEntryAndExit_nativeThrowing()
{
- /* This function was changed from old backend. JSC return more Entrys / Exits, (exactly +1)
+ /* This function was changed from old backend. JSC return more Entries / Exits, (exactly +1)
in exception creation time */
QScriptEngine eng;
@@ -2356,7 +2356,7 @@ void tst_QScriptEngineAgent::hasUncaughtException()
QVERIFY2(spy->isPass(), "At least one of a functionExit event should set hasUncaughtException flag.");
spy->reset();
- // Check catched exception.
+ // Check caught exception.
eng.evaluate("function innerFoo() { throw new Error('ciao') }");
eng.evaluate("function foo() {try { innerFoo() } catch (e) {} }");
scriptValue = QScriptValue(eng.globalObject().property("foo")).call();
diff --git a/tests/auto/qsortfilterproxymodel/tst_qsortfilterproxymodel.cpp b/tests/auto/qsortfilterproxymodel/tst_qsortfilterproxymodel.cpp
index 30589a89f6..e96e049698 100644
--- a/tests/auto/qsortfilterproxymodel/tst_qsortfilterproxymodel.cpp
+++ b/tests/auto/qsortfilterproxymodel/tst_qsortfilterproxymodel.cpp
@@ -3291,7 +3291,7 @@ public:
// It would be possible to use only the modelReset signal of the source model to clear
// the data in *this, however, this requires that the slot is connected
// before QSortFilterProxyModel::setSourceModel is called, and even then depends
- // on the order of invokation of slots being the same as the order of connection.
+ // on the order of invocation of slots being the same as the order of connection.
// ie, not reliable.
// connect(sourceModel, SIGNAL(modelReset()), SLOT(resetInternalData()));
QSortFilterProxyModel::setSourceModel(sourceModel);
diff --git a/tests/auto/qstylesheetstyle/tst_qstylesheetstyle.cpp b/tests/auto/qstylesheetstyle/tst_qstylesheetstyle.cpp
index a4fc1a9dd6..9d742ece2d 100644
--- a/tests/auto/qstylesheetstyle/tst_qstylesheetstyle.cpp
+++ b/tests/auto/qstylesheetstyle/tst_qstylesheetstyle.cpp
@@ -451,7 +451,7 @@ void tst_QStyleSheetStyle::widgetStyle()
window2->setStyleSheet("");
qApp->setStyle(0);
- qApp->setStyleSheet("may_insanity_prevail { }"); // app has styleshet
+ qApp->setStyleSheet("may_insanity_prevail { }"); // app has stylesheet
QCOMPARE(window1->style(), qApp->style());
QCOMPARE(window1->style()->metaObject()->className(), "QStyleSheetStyle");
QCOMPARE(widget1->style()->metaObject()->className(), "QStyleSheetStyle"); // check the child
diff --git a/tests/auto/qsvgrenderer/tst_qsvgrenderer.cpp b/tests/auto/qsvgrenderer/tst_qsvgrenderer.cpp
index 64f156f90f..e350d1e749 100644
--- a/tests/auto/qsvgrenderer/tst_qsvgrenderer.cpp
+++ b/tests/auto/qsvgrenderer/tst_qsvgrenderer.cpp
@@ -1242,7 +1242,7 @@ void tst_QSvgRenderer::testStopOffsetOpacity()
void tst_QSvgRenderer::testUseElement()
{
static const char *svgs[] = {
- //Use refering to non group node (1)
+ //Use referring to non group node (1)
"<svg viewBox = \"0 0 200 200\">"
" <polygon points=\"20,20 50,120 100,10 40,80 50,80\"/>"
" <polygon points=\"20,80 50,180 100,70 40,140 50,140\" fill= \"red\" stroke = \"blue\" fill-opacity = \"0.7\" fill-rule = \"evenodd\" stroke-width = \"3\"/>"
@@ -1263,7 +1263,7 @@ void tst_QSvgRenderer::testUseElement()
" <use y = \"60\" xlink:href = \"#usedPolyline\" fill = \" red\" stroke = \"blue\" fill-opacity = \"0.7\" fill-rule = \"evenodd\"/>"
" </g>"
"</svg>",
- //Use refering to non group node (2)
+ //Use referring to non group node (2)
"<svg viewBox = \"0 0 200 200\">"
" <polygon points=\"20,20 50,120 100,10 40,80 50,80\" fill = \"green\" fill-rule = \"nonzero\" stroke = \"purple\" stroke-width = \"4\" stroke-dasharray = \"1,1,3,1\" stroke-offset = \"3\" stroke-miterlimit = \"6\" stroke-linecap = \"butt\" stroke-linejoin = \"round\"/>"
" <polygon points=\"20,80 50,180 100,70 40,140 50,140\" fill= \"red\" stroke = \"blue\" fill-opacity = \"0.7\" fill-rule = \"evenodd\" stroke-width = \"3\" stroke-dasharray = \"1,1,1,1\" stroke-offset = \"5\" stroke-miterlimit = \"3\" stroke-linecap = \"butt\" stroke-linejoin = \"square\"/>"
@@ -1284,7 +1284,7 @@ void tst_QSvgRenderer::testUseElement()
" <use y = \"60\" xlink:href = \"#usedPolyline\" fill= \"red\" stroke = \"blue\" fill-opacity = \"0.7\" fill-rule = \"evenodd\" />"
" </g>"
"</svg>",
- //Use refering to group node
+ //Use referring to group node
"<svg viewBox = \"0 0 200 200\">"
" <g>"
" <circle cx=\"0\" cy=\"0\" r=\"100\" fill = \"red\" fill-opacity = \"0.6\"/>"
diff --git a/tests/auto/qtextcodec/tst_qtextcodec.cpp b/tests/auto/qtextcodec/tst_qtextcodec.cpp
index 049af796d9..4813f90652 100644
--- a/tests/auto/qtextcodec/tst_qtextcodec.cpp
+++ b/tests/auto/qtextcodec/tst_qtextcodec.cpp
@@ -496,7 +496,7 @@ void tst_QTextCodec::flagEFBFBF() const
start.append("?>");
}
- /* When 0xEFBFBF is preceeded by what seems to be an arbitrary character,
+ /* When 0xEFBFBF is preceded by what seems to be an arbitrary character,
* QTextCodec fails to flag it. */
{
QByteArray start("B");
diff --git a/tests/auto/qtextcursor/tst_qtextcursor.cpp b/tests/auto/qtextcursor/tst_qtextcursor.cpp
index bb5a212567..2b0ba422e0 100644
--- a/tests/auto/qtextcursor/tst_qtextcursor.cpp
+++ b/tests/auto/qtextcursor/tst_qtextcursor.cpp
@@ -1302,7 +1302,7 @@ void tst_QTextCursor::selectVisually()
cursor.setPosition(6); // somewhere in the long paragraph.
cursor.select(QTextCursor::LineUnderCursor);
- // since we are not yet layed-out, we expect the whole paragraph to be selected.
+ // since we are not yet laid-out, we expect the whole paragraph to be selected.
QCOMPARE(cursor.position(), 77);
QCOMPARE(cursor.anchor(), 4);
}
diff --git a/tests/auto/qvector/tst_qvector.cpp b/tests/auto/qvector/tst_qvector.cpp
index c6f85d4620..227ef49b88 100644
--- a/tests/auto/qvector/tst_qvector.cpp
+++ b/tests/auto/qvector/tst_qvector.cpp
@@ -155,7 +155,7 @@ void tst_QVector::capacity() const
{
QVector<QString> myvec;
- // TODO: is this guarenteed? seems a safe assumption, but I suppose preallocation of a
+ // TODO: is this guaranteed? seems a safe assumption, but I suppose preallocation of a
// few items isn't an entirely unforseeable possibility.
QVERIFY(myvec.capacity() == 0);
diff --git a/tests/auto/qwizard/tst_qwizard.cpp b/tests/auto/qwizard/tst_qwizard.cpp
index b2656db005..d4b0c795d4 100644
--- a/tests/auto/qwizard/tst_qwizard.cpp
+++ b/tests/auto/qwizard/tst_qwizard.cpp
@@ -923,7 +923,7 @@ void tst_QWizard::setOption_IndependentPages()
CHECK_PAGE_INIT(11, 10, 11, 10, 10, 10);
// Now, turn on the option and check that they're called at the
- // appropiate times (which aren't the same).
+ // appropriate times (which aren't the same).
wizard.setOption(QWizard::IndependentPages, true);
CHECK_PAGE_INIT(11, 10, 11, 10, 10, 10);
diff --git a/tests/auto/qwritelocker/tst_qwritelocker.cpp b/tests/auto/qwritelocker/tst_qwritelocker.cpp
index c49e29fe51..a06431a5e1 100644
--- a/tests/auto/qwritelocker/tst_qwritelocker.cpp
+++ b/tests/auto/qwritelocker/tst_qwritelocker.cpp
@@ -177,7 +177,7 @@ void tst_QWriteLocker::unlockAndRelockTest()
releaseThread();
waitForThread();
- // lock has been explicity relocked via QWriteLocker
+ // lock has been explicitly relocked via QWriteLocker
QVERIFY(!thread->lock.tryLockForWrite());
releaseThread();
diff --git a/tests/auto/qwswindowsystem/tst_qwswindowsystem.cpp b/tests/auto/qwswindowsystem/tst_qwswindowsystem.cpp
index 72fd41a6cd..80de6e96ad 100644
--- a/tests/auto/qwswindowsystem/tst_qwswindowsystem.cpp
+++ b/tests/auto/qwswindowsystem/tst_qwswindowsystem.cpp
@@ -536,12 +536,12 @@ void tst_QWSWindowSystem::dontFlushUnitializedWindowSurfaces()
// At this point w has a windowsurface but it's completely covered by
// the directpainter so nothing will be painted here and the
- // windowsurface contains unitialized data.
+ // windowsurface contains uninitialized data.
QApplication::processEvents();
QCOMPARE(p.allocatedRegion(), QRegion(r));
QCOMPARE(w.visibleRegion(), QRegion());
- fillWindowSurface(&w, Qt::black); // fill with "unitialized" data
+ fillWindowSurface(&w, Qt::black); // fill with "uninitialized" data
p.setRegion(QRegion());
@@ -569,7 +569,7 @@ void tst_QWSWindowSystem::dontFlushUnitializedWindowSurfaces()
QApplication::processEvents();
QCOMPARE(p.allocatedRegion(), QRegion(r));
QCOMPARE(w.visibleRegion(), QRegion());
- fillWindowSurface(&w, Qt::black); // fill with "unitialized" data
+ fillWindowSurface(&w, Qt::black); // fill with "uninitialized" data
p.setRegion(QRegion());
diff --git a/tests/auto/selftests/subtest/tst_subtest.cpp b/tests/auto/selftests/subtest/tst_subtest.cpp
index 2301fa6c51..4404a5103f 100644
--- a/tests/auto/selftests/subtest/tst_subtest.cpp
+++ b/tests/auto/selftests/subtest/tst_subtest.cpp
@@ -153,7 +153,7 @@ void tst_Subtest::test3()
QFETCH(QString, str);
- // second and third time we call this it shoud FAIL
+ // second and third time we call this it should FAIL
QCOMPARE(str, QString("hello0"));
printf("test2 end\n");
diff --git a/tests/auto/uiloader/tst_screenshot/main.cpp b/tests/auto/uiloader/tst_screenshot/main.cpp
index 3a33994bb2..707a540091 100644
--- a/tests/auto/uiloader/tst_screenshot/main.cpp
+++ b/tests/auto/uiloader/tst_screenshot/main.cpp
@@ -39,7 +39,7 @@
**
****************************************************************************/
/*
- * This programm takes a *.ui file and an output dir as argument in order to
+ * This program takes a *.ui file and an output dir as argument in order to
* create a screenshot of the widget defined in the ui file.
*
* The screenshot is saved in the output dir (default current dir), ".png" is
diff --git a/tests/auto/qnetworksession/test/tst_qnetworksession.cpp b/tests/auto/qnetworksession/test/tst_qnetworksession.cpp
index f01a9dcca7..68d104d650 100644
--- a/tests/auto/qnetworksession/test/tst_qnetworksession.cpp
+++ b/tests/auto/qnetworksession/test/tst_qnetworksession.cpp
@@ -1413,15 +1413,15 @@ void tst_QNetworkSession::outOfProcessSession()
}
}
// A convinience / helper function for testcases. Return the first matching configuration.
// Ignores configurations in other than 'discovered' -state. Returns invalid (QNetworkConfiguration())
// if none found.
QNetworkConfiguration suitableConfiguration(QString bearerType, QNetworkConfiguration::Type configType) {
-
+
// Refresh configurations and derive configurations matching given parameters.
QNetworkConfigurationManager mgr;
QSignalSpy updateSpy(&mgr, SIGNAL(updateCompleted()));
-
+
mgr.updateConfigurations();
QTRY_NOOP(updateSpy.count() == 1);
if (updateSpy.count() != 1) {
@@ -1430,13 +1430,13 @@ QNetworkConfiguration suitableConfiguration(QString bearerType, QNetworkConfigur
}
QList<QNetworkConfiguration> discoveredConfigs = mgr.allConfigurations(QNetworkConfiguration::Discovered);
foreach(QNetworkConfiguration config, discoveredConfigs) {
- if ((config.state() & QNetworkConfiguration::Active) == QNetworkConfiguration::Active) {
+ if ((config.state() & QNetworkConfiguration::Active) == QNetworkConfiguration::Active) {
discoveredConfigs.removeOne(config);
} else if (config.type() != configType) {
// qDebug() << "Dumping config because type (IAP/SNAP) mismatches: " << config.name();
discoveredConfigs.removeOne(config);
} else if ((config.type() == QNetworkConfiguration::InternetAccessPoint) &&
- bearerType == "cellular") { // 'cellular' bearertype is for convinience
+ bearerType == "cellular") { // 'cellular' bearertype is for convenience
if (config.bearerName() != "2G" &&
config.bearerName() != "CDMA2000" &&
config.bearerName() != "WCDMA" &&
@@ -1458,8 +1458,8 @@ QNetworkConfiguration suitableConfiguration(QString bearerType, QNetworkConfigur
}
}
-// A convinience-function: updates configurations and waits that they are updated.
-void updateConfigurations()
+// A convenience-function: updates configurations and waits that they are updated.
+void updateConfigurations()
{
QNetworkConfigurationManager mgr;
QSignalSpy updateSpy(&mgr, SIGNAL(updateCompleted()));
@@ -1467,7 +1467,7 @@ void updateConfigurations()
QTRY_NOOP(updateSpy.count() == 1);
}
// A convinience-function: updates and prints all available confiurations and their states
void printConfigurations()
{
QNetworkConfigurationManager manager;
@@ -1480,7 +1480,7 @@ void printConfigurations()
}
}
// A convinience function for test-cases: opens the given configuration and return
// true if it was done gracefully.
bool openSession(QNetworkSession *session) {
bool result = true;
@@ -1549,7 +1549,7 @@ bool openSession(QNetworkSession *session) {
// Helper function for closing opened session. Performs checks that
// session is closed gradefully (e.g. signals). Function does not delete
// the session. The lastSessionOnConfiguration (true by default) is used to
-// tell if there are more sessions open, basing on same configration. This
+// tell if there are more sessions open, basing on same configuration. This
// impacts the checks made.
bool closeSession(QNetworkSession *session, bool lastSessionOnConfiguration) {
if (!session) {
@@ -1413,15 +1413,15 @@ void tst_QNetworkSession::outOfProcessSession()
}
}
-// A convinience / helper function for testcases. Return the first matching configuration.
+// A convenience / helper function for testcases. Return the first matching configuration.
// Ignores configurations in other than 'discovered' -state. Returns invalid (QNetworkConfiguration())
// if none found.
@@ -1467,7 +1467,7 @@ void updateConfigurations()
QTRY_NOOP(updateSpy.count() == 1);
}
-// A convinience-function: updates and prints all available confiurations and their states
+// A convenience-function: updates and prints all available confiurations and their states
void printConfigurations()
{
@@ -1480,7 +1480,7 @@ void printConfigurations()
}
}
-// A convinience function for test-cases: opens the given configuration and return
+// A convenience function for test-cases: opens the given configuration and return
// true if it was done gracefully.
bool openSession(QNetworkSession *session) {